@@ -1,13 +1,11 @@
-from six import python_2_unicode_compatible
-
-from quickbooks.objects.detailline import DetailLine, ItemBasedExpenseLine, AccountBasedExpenseLine
+from quickbooks.objects.detailline import DetailLine, ItemBasedExpenseLine, AccountBasedExpenseLine, \
+    TDSLine
 from .base import Ref, LinkedTxn, QuickbooksManagedObject, QuickbooksTransactionEntity, \
     LinkedTxnMixin
 from .tax import TxnTaxDetail
 from ..mixins import DeleteMixin
 
 
-@python_2_unicode_compatible
 class Bill(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: A Bill entity is an AP transaction representing a request-for-payment from a third party for
@@ -26,11 +24,13 @@ class Bill(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity, Li
 
     list_dict = {
         "Line": DetailLine,
+        "LinkedTxn": LinkedTxn,
     }
 
     detail_dict = {
         "ItemBasedExpenseLineDetail": ItemBasedExpenseLine,
         "AccountBasedExpenseLineDetail": AccountBasedExpenseLine,
+        "TDSLineDetail": TDSLine,
     }
 
     qbo_object_name = "Bill"
@@ -76,4 +76,3 @@ class Bill(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity, Li
         ref.value = self.Id
 
         return ref
-
