@@ -1,8 +1,6 @@
-from six import python_2_unicode_compatible
 from .base import Address, PhoneNumber, QuickbooksManagedObject, QuickbooksTransactionEntity, Ref
 
 
-@python_2_unicode_compatible
 class Employee(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: Employee represents the people who are working for the company.
